---
name: Feature request
about: Suggest an idea for this project

---

## Describe your use-case
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

## Describe the solution you would like to see for your use-case
A clear and concise description of what you want to happen.
